=== modified file 'branchview/linegraph.py'
--- branchview/linegraph.py	2008-05-04 18:16:01 +0000
+++ branchview/linegraph.py	2008-06-29 15:54:40 +0000
@@ -12,8 +12,8 @@
 from bzrlib.revision import NULL_REVISION
 from bzrlib.tsort import merge_sort
 
-def linegraph(repository, start_revs, maxnum, broken_line_length = None,
-              graph_data = True, mainline_only = False):
+def linegraph(graph, start_revs, maxnum=None, broken_line_length=None,
+              graph_data=True, mainline_only=False):
     """Produce a directed graph of a bzr repository.
 
     Returns a tuple of (line_graph, revid_index, columns_len) where
@@ -43,7 +43,6 @@
     curved, kinked, etc.) and to pick the actual colours for each index.
     """
     
-    graph = repository.get_graph()
     graph_parents = {}
     ghosts = set()
     graph_children = {}

=== modified file 'branchview/treeview.py'
--- branchview/treeview.py	2008-06-28 15:45:39 +0000
+++ branchview/treeview.py	2008-06-29 15:47:30 +0000
@@ -285,7 +285,7 @@
         show_graph = self.graph_column.get_visible()
 
         self.branch.lock_read()
-        (linegraphdata, index, columns_len) = linegraph(self.branch.repository,
+        (linegraphdata, index, columns_len) = linegraph(self.branch.repository.get_graph(),
                                                         (self.start,) , # Sequence of start revisions
                                                         self.maxnum, 
                                                         broken_line_length,

=== modified file 'tests/__init__.py'
--- tests/__init__.py	2007-10-30 21:15:13 +0000
+++ tests/__init__.py	2008-06-29 15:54:40 +0000
@@ -27,6 +27,7 @@
     testmod_names = [
         'test_commit',
         'test_diff',
+        'test_linegraph',
         'test_preferences',
         'test_history',
         ]

=== added file 'tests/test_linegraph.py'
--- tests/test_linegraph.py	1970-01-01 00:00:00 +0000
+++ tests/test_linegraph.py	2008-06-29 15:54:40 +0000
@@ -0,0 +1,45 @@
+# Copyright (C) 2008 Jelmer Vernooij <jelmer@samba.org>
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
+"""Test the linegraph functionality."""
+
+import os
+
+import gtk
+
+from bzrlib import (
+	graph,
+    tests,
+    )
+from bzrlib.util import bencode
+
+from bzrlib.plugins.gtk.branchview.linegraph import linegraph
+
+
+class TestLinegraph(tests.TestCase):
+	def get_graph(self, dict):
+		return graph.Graph(graph.DictParentsProvider(dict))
+
+	def test_simple(self):
+		lg = linegraph(self.get_graph({"A": ("B", "C"), "B": ()}), ["A"])
+		self.assertEquals(lg,  
+            ([
+               ['A', (0, 0), [(0, 0, 0)], ['B'], [], (2,)],
+               ['B', (0, 0), [], (), ['A'], (1,)]
+             ],
+             {'A': 0, 'B': 1},
+             1))
+

=== modified file 'viz/branchwin.py'
--- viz/branchwin.py	2008-06-29 19:34:29 +0000
+++ viz/branchwin.py	2008-06-06 17:46:26 +0000
@@ -18,10 +18,9 @@
 from bzrlib.plugins.gtk.tags import AddTagDialog
 from bzrlib.plugins.gtk.preferences import PreferencesWindow
 from bzrlib.plugins.gtk.branchview import TreeView, treemodel
-
-from bzrlib.config import BranchConfig, GlobalConfig
 from bzrlib.revision import Revision, NULL_REVISION
-from bzrlib.trace import mutter
+from bzrlib.config import BranchConfig
+from bzrlib.config import GlobalConfig
 
 class BranchWindow(Window):
     """Branch window.
@@ -229,15 +228,6 @@
         branch_menu.add(gtk.MenuItem("Pu_ll Revisions"))
         branch_menu.add(gtk.MenuItem("Pu_sh Revisions"))
 
-        try:
-            from bzrlib.plugins import search
-        except ImportError:
-            mutter("Didn't find search plugin")
-        else:
-            branch_index_menuitem = gtk.MenuItem("_Index")
-            branch_index_menuitem.connect('activate', self._branch_index_cb)
-            branch_menu.add(branch_index_menuitem)
-
         help_menu = gtk.Menu()
         help_menuitem = gtk.MenuItem("_Help")
         help_menuitem.set_submenu(help_menu)
@@ -466,10 +456,6 @@
         finally:
             self.treeview.set_sensitive(True)
 
-    def _branch_index_cb(self, w):
-        from bzrlib.plugins.search import index as _mod_index
-        _mod_index.index_url(self.branch.base)
-
     def _about_dialog_cb(self, w):
         from bzrlib.plugins.gtk.about import AboutDialog
 

